Init

Enum Init 

pub enum Init {
    Data {
        bytes: Vec<u8>,
        count: u64,
        stride: u32,
    },
    Reserve {
        count: u64,
        stride: u32,
    },
}
Initial contents for one field of an Buffer record.

Variants



Data

Fields

bytes: Vec<u8>
count: u64
stride: u32


Reserve

Fields

count: u64
stride: u32

Implementations

Source

impl Init

pub fn data<T: StructuredBufferElement>(data: &[T]) -> Self

Upload a typed slice at acquisition (copied; not aliased).

pub fn reserve<T: StructuredBufferElement>(count: u64) -> Self

Reserve uninitialized space for count elements of type T.

pub fn zeros<T: StructuredBufferElement>(count: u64) -> Self

Reserve zero-initialized space for count elements of type T.